package org.rcisoft.integration.jieLink.Controller;

import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.integration.jieLink.dto.JieLinkDoorRecordDto;
import org.rcisoft.integration.jieLink.dto.JieLinkResultDto;
import org.rcisoft.integration.jieLink.service.IJieLinkService;
import org.rcisoft.sys.sysuser.entity.SysUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping("/jieLinkInter")
public class JieLinkInterController {

    @Autowired
    private IJieLinkService jieLinkService;


    @CyOpeLogAnno(title = "jieLinkInter-捷顺道闸上传门禁记录", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="捷顺对接集成-门禁数据上传", notes="门禁数据上传")
    @PostMapping(value = "/doorrecord")
    public JieLinkResultDto addDoorrecord(@RequestBody JieLinkDoorRecordDto recodeDto) {
        JieLinkResultDto result = new JieLinkResultDto();
        if(recodeDto!=null && StringUtils.isNotBlank(recodeDto.getRecordId())){
            /**
             * 开始处理上传的门禁记录
             * 1、检查访客人员是否存在，不存在是否还需要新增
             * 2、检查设备系统内是否存在，不存在返回错误信息
             * 3、保存门禁记录信息，按照年划分
             */
            try{
                JieLinkResultDto jieLinkResultDto = jieLinkService.saveDoorRecordInfo(recodeDto);
                if(jieLinkResultDto!=null){
                    result = jieLinkResultDto;
                }else{
                    result.setCode("SYSTEM_ERROR");
                    result.setMsg("上传记录出现异常，请重新上传");
                }
            }catch (Exception ex){
                log.error(ex.getMessage(),ex);
                result.setCode("SYSTEM_ERROR");
                result.setMsg("上传记录出现异常，请重新上传");
            }
        }else{
            result.setCode("ILLEGAL_ARGUMENT");
            result.setMsg("参数缺失，请检查请求实体信息");
        }
        return result;
    }


    @ApiOperation(value="捷顺对接集成-同步设备信息", notes="同步设备信息")
    @GetMapping(value = "/syncDeviceData")
    public JieLinkResultDto syncDeviceData() {
        jieLinkService.syncDeviceInfo();
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("同步完成");
        result.setCode("0");
        return result;
    }

    @ApiOperation(value="捷顺对接集成-获取部门信息", notes="获取部门信息")
    @GetMapping(value = "/getDeptList")
    public JieLinkResultDto getDeptList() {
        jieLinkService.getDeptList();
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("同步完成");
        result.setCode("0");
        return result;
    }

    @ApiOperation(value="捷顺对接集成-获取部门信息", notes="获取部门信息")
    @GetMapping(value = "/delUser")
    public JieLinkResultDto delUser(String personId) {
        SysUser delUser = new SysUser();
        delUser.setPersonId(personId);
        jieLinkService.pushDelUserData(delUser);
        JieLinkResultDto result = new JieLinkResultDto();
        result.setMsg("删除完成");
        result.setCode("0");
        return result;
    }


}
